@@ -49,9 +49,11 @@ from assertionlib.ndrepr import aNDRepr
 
 from .perp_surface import get_surface_vec
 from ..mol_utils import get_index, round_coords  # noqa: F401
+from ..utils import AnchorTup
 from ..workflows import WorkFlow, HDF5_INDEX, MOL, OPT
 from ..settings_dataframe import SettingsDataFrame
 from ..data_handling import mol_to_file, WARN_MAP
+from ..utils import AllignmentTup, AllignmentEnum
 
 __all__ = ['init_qd_construction']
 
@@ -201,9 +203,13 @@ def _get_df(core_index: pd.MultiIndex,
     return SettingsDataFrame(data, index=index, columns=columns, settings=settings)
 
 
-def ligand_to_qd(core: Molecule, ligand: Molecule, path: str,
-                 allignment: str = 'sphere',
-                 idx_subset: Optional[Iterable[int]] = None) -> Molecule:
+def ligand_to_qd(
+    core: Molecule,
+    ligand: Molecule,
+    path: str,
+    allignment: AllignmentTup,
+    idx_subset: "None | Iterable[int]" = None,
+) -> Molecule:
     """Function that handles quantum dot (qd, *i.e.* core + all ligands) operations.
 
     Combine the core and ligands and assign properties to the quantom dot.
@@ -249,19 +255,30 @@ def ligand_to_qd(core: Molecule, ligand: Molecule, path: str,
     ligand.properties.dummies.properties.anchor = True
 
     # Attach the rotated ligands to the core, returning the resulting strucutre (PLAMS Molecule).
-    if allignment == 'sphere':
-        vec2 = np.array(core.get_center_of_mass()) - sanitize_dim_2(core.properties.dummies)
+    anchor = sanitize_dim_2(core.properties.dummies)
+    if allignment.kind == AllignmentEnum.SPHERE:
+        vec2 = np.array(core.get_center_of_mass()) - anchor
         vec2 /= np.linalg.norm(vec2, axis=1)[..., None]
-    elif allignment == 'surface':
-        if isinstance(core.properties.dummies, np.ndarray):
-            anchor = core.properties.dummies
-        else:
-            anchor = core.as_array(core.properties.dummies)
+    elif allignment.kind == AllignmentEnum.SURFACE:
         vec2 = -get_surface_vec(np.array(core)[idx_subset_], anchor)
     else:
-        raise ValueError(repr(allignment))
+        raise ValueError(f"Unknown allignment kind: {allignment.kind}")
+    if allignment.invert:
+        vec2 *= -1
 
-    lig_array = rot_mol(ligand, vec1, vec2, atoms_other=core.properties.dummies, core=core, idx=idx)
+    # Rotate the ligands
+    anchor_tup = ligand.properties.anchor_tup
+    if anchor_tup.dihedral is None:
+        lig_array = rot_mol(
+            ligand, vec1, vec2, atoms_other=core.properties.dummies, core=core, idx=idx
+        )
+    else:
+        lig_array = rot_mol(
+            ligand, vec1, vec2, atoms_other=core.properties.dummies, core=core,
+            idx=idx, anchor_tup=anchor_tup,
+        )
+
+    # Combine the ligands and core
     qd = core.copy()
     array_to_qd(ligand, lig_array, mol_out=qd)
     qd.round_coords()
@@ -281,6 +298,18 @@ def ligand_to_qd(core: Molecule, ligand: Molecule, path: str,
     return qd
 
 
+def _get_dihedrals(mat1: np.ndarray, mat2: np.ndarray, vec3: np.ndarray) -> np.ndarray:
+    """Get the dihedral angle between three vectors in radian."""
+    v1v2 = np.cross(-mat1, mat2)
+    v2v3 = np.cross(vec3, mat2)
+    v1v2_v2v3 = np.cross(v1v2, v2v3)
+    v2_norm_v2 = mat2 / np.linalg.norm(mat2, axis=1)[..., None]
+    return np.arctan2(
+        np.einsum("ij,ij->i", v1v2_v2v3, v2_norm_v2),
+        np.einsum("ij,ij->i", v1v2, v2v3),
+    )
+
+
 def _get_rotmat1(vec1: np.ndarray, vec2: np.ndarray) -> np.ndarray:
     """Calculate the rotation matrix for rotating **vec1** to **vec2**.
 
@@ -345,7 +374,11 @@ def _get_rotmat1(vec1: np.ndarray, vec2: np.ndarray) -> np.ndarray:
         return ret
 
 
-def _get_rotmat2(vec: np.ndarray, step: float = (1/16)) -> np.ndarray:
+def _get_rotmat2(
+    vec: np.ndarray,
+    step: float = 1/16,
+    angle_vec: "None | np.ndarray" = None,
+) -> np.ndarray:
     r"""Calculate the rotation matrix for rotating m vectors along their axes, each vector yielding :math:`k = (2 / step)` possible rotations.
 
     Paramaters
@@ -367,10 +400,13 @@ def _get_rotmat2(vec: np.ndarray, step: float = (1/16)) -> np.ndarray:
                   [v3, zero, -v1],
                   [-v2, v1, zero]]).T
 
-    step_range = np.pi * np.arange(0.0, 2.0, step)
-    a1 = np.sin(step_range)[:, None, None, None]
-    a2 = (1 - np.cos(step_range))[:, None, None, None]
-
+    if angle_vec is None:
+        step_range = np.pi * np.arange(0.0, 2.0, step)
+        a1 = np.sin(step_range)[:, None, None, None]
+        a2 = 1 - np.cos(step_range)[:, None, None, None]
+    else:
+        a1 = np.sin(angle_vec)[:, None, None]
+        a2 = 1 - np.cos(angle_vec)[:, None, None]
     return np.identity(3) + a1 * w + a2 * w@w
 
 
@@ -383,7 +419,8 @@ def rot_mol(xyz_array: np.ndarray,
             bond_length: Optional[int] = None,
             step: float = 1/16,
             dist_to_self: bool = True,
-            ret_min_dist: bool = False) -> np.ndarray:
+            ret_min_dist: bool = False,
+            anchor_tup: "None | AnchorTup" = None) -> np.ndarray:
     r"""Rotate **xyz_array**.
 
     Paramaters
@@ -441,6 +478,19 @@ def rot_mol(xyz_array: np.ndarray,
     rotmat1 = _get_rotmat1(vec1, vec2)
     xyz = xyz@rotmat1
 
+    # Code-path for fixed-angle dihedrals
+    if anchor_tup is not None:
+        i, j, *_ = anchor_tup.anchor_idx
+        vec3 = xyz[:, i] - xyz[:, j]
+        dihedral_vec = _get_dihedrals(vec3, vec2, vec1)
+        dihedral_vec -= anchor_tup.dihedral
+        rotmat2 = _get_rotmat2(vec2, angle_vec=dihedral_vec)
+        xyz = np.matmul(xyz, rotmat2, out=xyz)
+
+        at_other = sanitize_dim_2(atoms_other)
+        xyz += (at_other - xyz[:, idx])[:, None]
+        return xyz
+
     # Create all k possible rotations of all m ligands
     rotmat2 = _get_rotmat2(vec2, step=step)
     xyz = np.swapaxes(xyz@rotmat2, 0, 1)
