@@ -39,7 +39,7 @@ from logging import Logger
 from os.path import join, isdir, isfile, exists
 from itertools import cycle, chain, repeat
 from contextlib import redirect_stdout
-from collections import abc
+from collections import abc, Counter
 from typing import (
     Iterable, Union, TypeVar, Mapping, Type, Generator, Iterator, Optional,
     Any, NoReturn, Dict, overload, Callable, NamedTuple, Tuple,
@@ -60,11 +60,13 @@ from scm.plams import (
 from .logger import logger
 from .mol_utils import to_atnum
 from .gen_job_manager import GenJobManager
+from ._mol_str_parser import FormatEnum
 
 __all__ = [
     'JOB_MAP', 'check_sys_var', 'dict_concatenate', 'get_template',
     'cycle_accumulate', 'iter_repeat', 'get_nearest_neighbors',
-    'log_traceback_locals', 'KindEnum', 'AnchorTup',
+    'log_traceback_locals', 'KindEnum', 'AnchorTup', 'AllignmentEnum',
+    'AllignmentTup', 'FormatEnum',
 ]
 
 JOB_MAP: Mapping[Type[Job], str] = MappingProxyType({
@@ -541,6 +543,13 @@ class KindEnum(enum.Enum):
     MEAN_TRANSLATE = 2
 
 
+class AllignmentEnum(enum.Enum):
+    """An enum with different core vector orientations (see :class:`AllignmentTup`)."""
+
+    SPHERE = 0
+    SURFACE = 1
+
+
 class AnchorTup(NamedTuple):
     """A named tuple with anchoring operation instructions."""
 
@@ -550,3 +559,27 @@ class AnchorTup(NamedTuple):
     anchor_idx: Tuple[int, ...] = ()
     remove: "None | Tuple[int, ...]" = None
     kind: KindEnum = KindEnum.FIRST
+    angle_offset: "None | float" = None
+    dihedral: "None | float" = None
+    group_format: FormatEnum = FormatEnum.SMILES
+
+
+class AllignmentTup(NamedTuple):
+    """A named tuple with core vector orientation options."""
+
+    kind: AllignmentEnum
+    invert: bool
+
+
+class MoleculeWarning(Warning, MoleculeError):
+    """A :exc:`Warning` subclass for :class:`~scm.plams.mol.molecule.Molecule` related errors."""
+
+
+def get_formula(mol: Molecule) -> str:
+    """Backport of the PLAMS <= 1.5.1 ``Molecule.get_formula`` method.
+
+    The resulting atoms are reported in alphabetical order,
+    contrary to the Hill system (that prioritizes ``CH`` pairs) utilized after 1.5.1.
+    """
+    dct = Counter(at.symbol for at in mol)
+    return "".join(f"{at}{i}" for at, i in sorted(dct.items()))
